==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/texture/texturewindow.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** texturewindow.h
*/
#ifndef __TEXTUREWINDOW_H__
#define __TEXTUREWINDOW_H__


#include <ktmainwindow.h>
#include <ktopwidget.h>
#include <knewpanner.h>
#include <ktoolbar.h>
#include <qpopupmenu.h>
#include "textureview.h"

class TextureWindow : public KTMainWindow
//class MainWin : public KTopLevelWidget
{
	Q_OBJECT
protected:
	KToolBar *tbtxtview;
	TextureView *tview;
	Preferences	prefs;
	QPopupMenu		*MPigment,*MNormal,*MFinish,*MInterior;
public:
	TextureWindow(char *name = 0L);
	~TextureWindow();

	void	paintEvent(QPaintEvent*);
	void	show();

};

#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/texture/texturewindow.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** texturewindow.h
*/
#ifndef __TEXTUREWINDOW_H__
#define __TEXTUREWINDOW_H__


#include <ktmainwindow.h>
#include <ktopwidget.h>
#include <knewpanner.h>
#include <ktoolbar.h>
#include <qpopupmenu.h>
#include "textureview.h"
#include "texturetoolbar.h"

class TextureWindow : public KTMainWindow
{
	Q_OBJECT
protected:
	KToolBar *tbtxtview;
	TextureView *tview;
	TextureListView	*tlview;
	Preferences	prefs;


public:
	TextureWindow(char *name = 0L);
	~TextureWindow();

	void	paintEvent(QPaintEvent*);
	void	show();

};

#endif
